@@ -1,20 +1,26 @@
 /*
- * This file is part of "The Java Telnet Application".
+ * This file is part of "JTA - Telnet/SSH for the JAVA(tm) platform".
  *
- * This is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
+ * (c) Matthias L. Jugel, Marcus Meißner 1996-2005. All Rights Reserved.
  *
- * "The Java Telnet Application" is distributed in the hope that it will be
- * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * Please visit http://javatelnet.org/ for updates and contact.
+ *
+ * --LICENSE NOTICE--
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this software; see the file COPYING.  If not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * --LICENSE NOTICE--
+ *
  */
 package de.mud.jta;
 
@@ -25,7 +31,17 @@ import de.mud.jta.event.ReturnFocusRequest;
 import de.mud.jta.event.SocketRequest;
 import de.mud.jta.event.SoundListener;
 
-import java.awt.*;
+import javax.swing.JApplet;
+import javax.swing.JFrame;
+import javax.swing.RootPaneContainer;
+import java.awt.BorderLayout;
+import java.awt.Button;
+import java.awt.Component;
+import java.awt.Menu;
+import java.awt.MenuBar;
+import java.awt.MenuItem;
+import java.awt.MenuShortcut;
+import java.awt.PrintJob;
 import java.awt.datatransfer.Clipboard;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
@@ -36,12 +52,13 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.net.URL;
 import java.util.Enumeration;
-import java.util.Hashtable;
+import java.util.Iterator;
+import java.util.Map;
 import java.util.Properties;
 import java.util.Vector;
 
 /**
- * <B>The Java Telnet Applet</B><P>
+ * <B>JTA - Telnet/SSH for the JAVA(tm) platform: Applet</B><P>
  * This is the implementation of whole set of applications. It's modular
  * structure allows to configure the software to act either as a sophisticated
  * terminal emulation and/or, adding the network backend, as telnet
@@ -54,15 +71,15 @@ import java.util.Vector;
  * <P>
  * <B>Maintainer:</B> Matthias L. Jugel
  *
- * @version $Id: Applet.java,v 2.35 2002/02/27 17:47:02 leo Exp $
- * @author Matthias L. Jugel, Marcus Meiner
+ * @version $Id: Applet.java 499 2005-09-29 08:24:54Z leo $
+ * @author Matthias L. Jugel, Marcus Meissner
  */
-public class Applet extends java.applet.Applet {
+public class Applet extends JApplet {
 
   private final static int debug = 0;
 
   private String frameTitle = null;
-  private java.awt.Container appletFrame;
+  private RootPaneContainer appletFrame;
 
   /** holds the defaults */
   private Properties options = new Properties();
@@ -84,8 +101,6 @@ public class Applet extends java.applet.Applet {
   private Clipboard clipboard;
   private boolean online = false;
 
-  private HelpFrame helpFrame = null;
-
   /**
    * Read all parameters from the applet configuration and
    * do initializations for the plugins and the applet.
@@ -175,22 +190,23 @@ public class Applet extends java.applet.Applet {
       frameTitle = options.getProperty("Applet.detach.title");
 
       if ((new Boolean(options.getProperty("Applet.detach"))).booleanValue()) {
-        if (frameTitle == null)
-          appletFrame = new Frame("jta: " + host + (port.equals("23")?"":" " + port));
-        else
-          appletFrame = new Frame(frameTitle);
-      } else
-        appletFrame = this;
+        if (frameTitle == null) {
+          appletFrame = (RootPaneContainer)new JFrame("jta: " + host + (port.equals("23")?"":" " + port));
+        } else {
+          appletFrame = (RootPaneContainer)new JFrame(frameTitle);
+        }
+      } else {
+        appletFrame = (RootPaneContainer)this;
+      }
+      appletFrame.getContentPane().setLayout(new BorderLayout());
 
-      appletFrame.setLayout(new BorderLayout());
-
-      Hashtable componentList = pluginLoader.getComponents();
-      Enumeration names = componentList.keys();
-      while (names.hasMoreElements()) {
-        String name = (String) names.nextElement();
+      Map componentList = pluginLoader.getComponents();
+      Iterator names = componentList.keySet().iterator();
+      while (names.hasNext()) {
+        String name = (String) names.next();
         Component c = (Component) componentList.get(name);
         if ((value = options.getProperty("layout." + name)) != null) {
-          appletFrame.add(value, c);
+          appletFrame.getContentPane().add(value, c);
         } else {
           System.err.println("jta: no layout property set for '" + name + "'");
           System.err.println("jta: ignoring '" + name + "'");
@@ -238,7 +254,7 @@ public class Applet extends java.applet.Applet {
 
         // set up the clipboard
         try {
-          clipboard = appletFrame.getToolkit().getSystemClipboard();
+          clipboard = appletFrame.getContentPane().getToolkit().getSystemClipboard();
           System.err.println("Applet: acquired system clipboard: " + clipboard);
         } catch (Exception e) {
           System.err.println("Applet: system clipboard access denied: " +
@@ -256,12 +272,12 @@ public class Applet extends java.applet.Applet {
                 .booleanValue())) {
           if ((new Boolean(options.getProperty("Applet.detach.fullscreen"))
                   .booleanValue()))
-            ((Frame) appletFrame)
-                    .setSize(appletFrame.getToolkit().getScreenSize());
+            ((JFrame) appletFrame)
+                    .setSize(appletFrame.getContentPane().getToolkit().getScreenSize());
           else
-            ((Frame) appletFrame).pack();
+            ((JFrame) appletFrame).pack();
 
-          ((Frame) appletFrame).show();
+          ((JFrame) appletFrame).show();
           pluginLoader.broadcast(new SocketRequest(host, Integer.parseInt(port)));
           pluginLoader.broadcast(new ReturnFocusRequest());
           close.setLabel(startText != null ? stopText : "Disconnect");
@@ -270,21 +286,23 @@ public class Applet extends java.applet.Applet {
 
         close.addActionListener(new ActionListener() {
           public void actionPerformed(ActionEvent evt) {
-            if (((Frame) appletFrame).isVisible()) {
+            if (((JFrame) appletFrame).isVisible()) {
               pluginLoader.broadcast(new SocketRequest());
-              ((Frame) appletFrame).setVisible(false);
+              ((JFrame) appletFrame).setVisible(false);
               close.setLabel(startText != null ? startText : "Connect");
             } else {
               if (frameTitle == null)
-                ((Frame) appletFrame)
+                ((JFrame) appletFrame)
                         .setTitle("jta: " + host + (port.equals("23")?"":" " + port));
               if ((new Boolean(options.getProperty("Applet.detach.fullscreen"))
                       .booleanValue()))
-                ((Frame) appletFrame)
-                        .setSize(appletFrame.getToolkit().getScreenSize());
+                ((JFrame) appletFrame)
+                        .setSize(appletFrame.getContentPane().getToolkit().getScreenSize());
               else
-                ((Frame) appletFrame).pack();
-              ((Frame) appletFrame).show();
+                ((JFrame) appletFrame).pack();
+              ((JFrame) appletFrame).show();
+              if (port == null || port.length() <= 0)
+		port = "23";
               getAppletContext().showStatus("Trying " + host + " " + port + " ...");
               pluginLoader.broadcast(new SocketRequest(host,
                                                        Integer.parseInt(port)));
@@ -294,8 +312,8 @@ public class Applet extends java.applet.Applet {
           }
         });
 
-        setLayout(new BorderLayout());
-        add("Center", close);
+        getContentPane().setLayout(new BorderLayout());
+        getContentPane().add("Center", close);
 
         // add a menu bar
         MenuBar mb = new MenuBar();
@@ -321,8 +339,8 @@ public class Applet extends java.applet.Applet {
           public void actionPerformed(ActionEvent evt) {
             if (pluginLoader.getComponents().get("Terminal") != null) {
               PrintJob printJob =
-                      appletFrame.getToolkit()
-                      .getPrintJob((Frame) appletFrame, "JTA Terminal", null);
+                      appletFrame.getContentPane().getToolkit()
+                      .getPrintJob((JFrame) appletFrame, "JTA Terminal", null);
               ((Component) pluginLoader.getComponents().get("Terminal"))
                       .print(printJob.getGraphics());
               printJob.end();
@@ -333,7 +351,7 @@ public class Applet extends java.applet.Applet {
         file.add(tmp = new MenuItem("Exit"));
         tmp.addActionListener(new ActionListener() {
           public void actionPerformed(ActionEvent evt) {
-            ((Frame) appletFrame).setVisible(false);
+            ((JFrame) appletFrame).setVisible(false);
             pluginLoader.broadcast(new SocketRequest());
             close.setLabel(startText != null ? startText : "Connect");
           }
@@ -362,11 +380,12 @@ public class Applet extends java.applet.Applet {
         });
         mb.add(edit);
 
-        Hashtable menuList = pluginLoader.getMenus();
-        names = menuList.keys();
-        while (names.hasMoreElements()) {
-          String name = (String) names.nextElement();
-          mb.add((Menu) menuList.get(name));
+        Map menuList = pluginLoader.getMenus();
+        names = menuList.keySet().iterator();
+        while (names.hasNext()) {
+          String name = (String) names.next();
+	  Object o = menuList.get(name);
+          if (o instanceof Menu) mb.add((Menu) o);
         }
 
         Menu help = new Menu("Help");
@@ -374,10 +393,7 @@ public class Applet extends java.applet.Applet {
         help.add(tmp = new MenuItem("General"));
         tmp.addActionListener(new ActionListener() {
           public void actionPerformed(ActionEvent e) {
-            if(helpFrame == null) {
-              helpFrame = new HelpFrame(options.getProperty("Help.url"));
-            }
-            helpFrame.setVisible(true);
+            Help.show(appletFrame.getContentPane(), options.getProperty("Help.url"));
           }
         });
         mb.setHelpMenu(help);
@@ -385,14 +401,14 @@ public class Applet extends java.applet.Applet {
         // only add the menubar if the property is true
         if ((new Boolean(options.getProperty("Applet.detach.menuBar"))
                 .booleanValue()))
-          ((Frame) appletFrame).setMenuBar(mb);
+          ((JFrame) appletFrame).setMenuBar(mb);
 
         // add window closing event handler
         try {
-          ((Frame) appletFrame).addWindowListener(new WindowAdapter() {
+          ((JFrame) appletFrame).addWindowListener(new WindowAdapter() {
             public void windowClosing(WindowEvent evt) {
               pluginLoader.broadcast(new SocketRequest());
-              ((Frame) appletFrame).setVisible(false);
+              ((JFrame) appletFrame).setVisible(false);
               close.setLabel(startText != null ? startText : "Connect");
             }
           });
@@ -405,15 +421,15 @@ public class Applet extends java.applet.Applet {
           public void online() {
             if (debug > 0) System.err.println("Terminal: online");
             online = true;
-            if (((Frame) appletFrame).isVisible() == false)
-              ((Frame) appletFrame).setVisible(true);
+            if (((JFrame) appletFrame).isVisible() == false)
+              ((JFrame) appletFrame).setVisible(true);
           }
 
           public void offline() {
             if (debug > 0) System.err.println("Terminal: offline");
             online = false;
             if (disconnectCloseWindow) {
-              ((Frame) appletFrame).setVisible(false);
+              ((JFrame) appletFrame).setVisible(false);
               close.setLabel(startText != null ? startText : "Connect");
             }
           }
