@@ -1,7 +1,7 @@
 /*
- * This file is part of "The Java Telnet Application".
+ * This file is part of "JTA - Telnet/SSH for the JAVA(tm) platform".
  *
- * (c) Matthias L. Jugel, Marcus Meissner 1996-2002. All Rights Reserved.
+ * (c) Matthias L. Jugel, Marcus Meißner 1996-2005. All Rights Reserved.
  *
  * Please visit http://javatelnet.org/ for updates and contact.
  *
@@ -15,7 +15,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -33,6 +33,7 @@ import de.mud.jta.PluginBus;
 import de.mud.jta.event.OnlineStatusListener;
 import de.mud.jta.event.ConfigurationListener;
 import de.mud.jta.event.TelnetCommandListener;
+import de.mud.jta.event.SetWindowSizeListener;
 import de.mud.jta.event.TerminalTypeRequest;
 import de.mud.jta.event.WindowSizeRequest;
 import de.mud.jta.event.LocalEchoRequest;
@@ -51,7 +52,7 @@ import java.io.IOException;
  * <P>
  * <B>Maintainer:</B> Matthias L. Jugel
  *
- * @version $Id: Telnet.java,v 2.16 2003/11/16 12:38:03 marcus Exp $
+ * @version $Id: Telnet.java 503 2005-10-24 07:34:13Z marcus $
  * @author Matthias L. Jugel, Marcus Meissner
  */
 public class Telnet extends Plugin implements FilterPlugin {
@@ -108,6 +109,16 @@ public class Telnet extends Plugin implements FilterPlugin {
       }
     });
 
+    bus.registerPluginListener(new SetWindowSizeListener() {
+      public void setWindowSize(int columns, int rows) {
+        try {
+	  handler.setWindowSize(columns,rows);
+        } catch (java.io.IOException e) {
+          System.err.println("IO Exception in set window size");
+        }
+      }
+    });
+
     bus.registerPluginListener(new ConfigurationListener() {
       public void setConfiguration(PluginConfig config) {
         configure(config);
