@@ -1,7 +1,7 @@
 /*
- * This file is part of "The Java Telnet Application".
+ * This file is part of "JTA - Telnet/SSH for the JAVA(tm) platform".
  *
- * (c) Matthias L. Jugel, Marcus Meissner 1996-2002. All Rights Reserved.
+ * (c) Matthias L. Jugel, Marcus Meißner 1996-2005. All Rights Reserved.
  *
  * Please visit http://javatelnet.org/ for updates and contact.
  *
@@ -15,7 +15,7 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -36,12 +36,12 @@ import java.lang.Byte;
  * <P>
  * <B>Maintainer:</B> Marcus Meissner
  *
- * @version $Id: TelnetProtocolHandler.java,v 2.18 2003/11/16 12:37:29 marcus Exp $
+ * @version $Id: TelnetProtocolHandler.java 503 2005-10-24 07:34:13Z marcus $
  * @author  Matthias L. Jugel, Marcus Meissner
  */
 public abstract class TelnetProtocolHandler {
   /** contains the current revision id */
-  public final static String ID = "$Id: TelnetProtocolHandler.java,v 2.18 2003/11/16 12:37:29 marcus Exp $";
+  public final static String ID = "$Id: TelnetProtocolHandler.java 503 2005-10-24 07:34:13Z marcus $";
   
   /** debug level */
   private final static int debug = 0;
@@ -138,6 +138,9 @@ public abstract class TelnetProtocolHandler {
 
   /** What IAC SB <xx> we are handling right now */
   private byte current_sb;
+  
+  /** current SB negotiation buffer */
+  private byte[] sbbuf;
 
   /** IAC - init sequence for telnet negotiation. */
   private final static byte IAC  = (byte)255;
@@ -201,20 +204,38 @@ public abstract class TelnetProtocolHandler {
     write(b);
   }
 
+  /**
+   * Send the new Window Size (via NAWS)
+   */
+  public void setWindowSize(int columns,int rows)
+    throws IOException {
+    if(debug > 2) System.err.println("sending NAWS");
+
+    if (receivedDX[TELOPT_NAWS] != DO) {
+    	System.err.println("not allowed to send NAWS? (DONT NAWS)");
+	return;
+    }
+    write(IAC);write(SB);write(TELOPT_NAWS);
+    write((byte) (columns >> 8));
+    write((byte) (columns & 0xff));
+    write((byte) (rows >> 8));
+    write((byte) (rows & 0xff));
+    write(IAC);write(SE);
+  }
+
 
   /**
    * Handle an incoming IAC SB &lt;type&gt; &lt;bytes&gt; IAC SE
    * @param type type of SB
    * @param sbata byte array as &lt;bytes&gt;
-   * @param sbcount nr of bytes. may be 0 too.
    */
-  private void handle_sb(byte type, byte[] sbdata, int sbcount) 
+  private void handle_sb(byte type, byte[] sbdata) 
     throws IOException {
     if(debug > 1) 
       System.err.println("TelnetIO.handle_sb("+type+")");
     switch (type) {
     case TELOPT_TTYPE:
-      if (sbcount>0 && sbdata[0]==TELQUAL_SEND) {
+      if (sbdata.length>0 && sbdata[0]==TELQUAL_SEND) {
         write(IACSB);write(TELOPT_TTYPE);write(TELQUAL_IS);
         /* FIXME: need more logic here if we use 
          * more than one terminal type
@@ -315,12 +336,10 @@ public abstract class TelnetProtocolHandler {
   public int negotiate(byte nbuf[])
   throws IOException
   {
-    byte sbbuf[] = new byte[tempbuf.length];
     int count = tempbuf.length;
     byte[] buf = tempbuf;
     byte sendbuf[] = new byte[3];
     byte b,reply;
-    int  sbcount = 0;
     int boffset = 0, noffset = 0;
     boolean dobreak = false;
 
@@ -378,7 +397,6 @@ public abstract class TelnetProtocolHandler {
         case SB:
           if(debug > 2) System.err.print("SB ");
           neg_state = STATE_IACSB;
-          sbcount = 0;
           break;
         default:
           if(debug > 2) System.err.print("<UNKNOWN "+b+" > ");
@@ -549,7 +567,7 @@ public abstract class TelnetProtocolHandler {
       case STATE_IACSBIAC:
         if(debug > 2) System.err.println(""+b+" ");
         if (b == IAC) {
-          sbcount = 0;
+	  sbbuf = new byte[0];
           current_sb = b;
           neg_state = STATE_IACSBDATA;
         } else {
@@ -565,7 +583,7 @@ public abstract class TelnetProtocolHandler {
           break;
         default:
           current_sb = b;
-          sbcount = 0;
+	  sbbuf = new byte[0];
           neg_state = STATE_IACSBDATA;
           break;
         }
@@ -577,7 +595,10 @@ public abstract class TelnetProtocolHandler {
           neg_state = STATE_IACSBDATAIAC;
           break;
         default:
-          sbbuf[sbcount++] = b;
+	  byte[] xsb = new byte[sbbuf.length+1];
+          System.arraycopy(sbbuf,0,xsb,0,sbbuf.length);
+	  sbbuf = xsb;
+          sbbuf[sbbuf.length-1] = b;
           break;
         }
         break;
@@ -586,15 +607,18 @@ public abstract class TelnetProtocolHandler {
         switch (b) {
         case IAC:
           neg_state = STATE_IACSBDATA;
-          sbbuf[sbcount++] = IAC;
+	  byte[] xsb = new byte[sbbuf.length+1];
+          System.arraycopy(sbbuf,0,xsb,0,sbbuf.length);
+	  sbbuf = xsb;
+          sbbuf[sbbuf.length-1] = IAC;
           break;
         case SE:
-          handle_sb(current_sb,sbbuf,sbcount);
+          handle_sb(current_sb,sbbuf);
           current_sb = 0;
           neg_state = STATE_DATA;
           break;
         case SB:
-          handle_sb(current_sb,sbbuf,sbcount);
+          handle_sb(current_sb,sbbuf);
           neg_state = STATE_IACSB;
           break;
         default:
