@@ -1,7 +1,7 @@
 /*
- * This file is part of "The Java Telnet Application".
+ * This file is part of "JTA - Telnet/SSH for the JAVA(tm) platform".
  *
- * (c) Matthias L. Jugel, Marcus Meiner 1996-2002. All Rights Reserved.
+ * (c) Matthias L. Jugel, Marcus Meißner 1996-2005. All Rights Reserved.
  *
  * Please visit http://javatelnet.org/ for updates and contact.
  *
@@ -30,6 +30,7 @@ package de.mud.terminal;
  */
 public interface VDUDisplay {
   public void redraw();
+  public void updateScrollBar();
 
   public void setVDUBuffer(VDUBuffer buffer);
   public VDUBuffer getVDUBuffer();
